import { __decorate, __metadata, __param } from 'tslib';
import { ɵɵdefineInjectable, Injectable, Component, ChangeDetectionStrategy, InjectionToken, Inject, Optional, Pipe, ChangeDetectorRef, Input, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { Title, DomSanitizer } from '@angular/platform-browser';
import { BehaviorSubject, of } from 'rxjs';
import { ActivatedRoute, RouterModule } from '@angular/router';
import { switchMap } from 'rxjs/operators';
import { CommonModule } from '@angular/common';

let DocsService = class DocsService {
    constructor() {
        this._menuItems$ = new BehaviorSubject(null);
    }
    get menuItems$() {
        return this._menuItems$.asObservable();
    }
    set menuItems(items) {
        this._menuItems = items;
        this._menuItems$.next(items);
    }
};
DocsService.ɵprov = ɵɵdefineInjectable({ factory: function DocsService_Factory() { return new DocsService(); }, token: DocsService, providedIn: "root" });
DocsService = __decorate([
    Injectable({ providedIn: 'root' })
], DocsService);

const baseTitle = (title) => {
    return title.includes('|') ? title.split(' | ')[0] : title;
};
const titleFromName = (name) => {
    return name.split(/(?=[A-Z])/).join(' ');
};
const titleFromTag = (tag) => {
    return tag.split('-').slice(1).map((word) => word.charAt(0).toUpperCase() + word.slice(1)).join(' ');
};

let ApiComponent = class ApiComponent {
    constructor(title, service) {
        this.title = title;
        this.service = service;
        this.service.menuItems = undefined;
        this.title.setTitle(`${baseTitle(this.title.getTitle())} | API`);
    }
};
ApiComponent.ctorParameters = () => [
    { type: Title },
    { type: DocsService }
];
ApiComponent = __decorate([
    Component({
        template: '<router-outlet></router-outlet>',
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [Title, DocsService])
], ApiComponent);

var FrameworkType;
(function (FrameworkType) {
    FrameworkType["angular"] = "angular";
    FrameworkType["javascript"] = "javascript";
    FrameworkType["vue"] = "vue";
})(FrameworkType || (FrameworkType = {}));
const DEMO_COMPONENTS = new InjectionToken('Demo components');
const GET_STARTED_URL = new InjectionToken('URL to get started from home');
const HOME_README = new InjectionToken('Injectable Home Readme');
const LIBRARY_API = new InjectionToken('The full library API');
const MODULE_DOCS = new InjectionToken('Demo components');
const MODULE_GET_STARTED_URL = new InjectionToken('URL to try a module');
const MODULE_NAME = new InjectionToken('Module name');
const MODULE_README = new InjectionToken('Injectable Web Components Readme');
const MODULE_TYPE = new InjectionToken('The framework the module is for');

let ApiDocComponent = class ApiDocComponent {
    constructor(title, route, api) {
        this.title = title;
        this.route = route;
        const module = this.route.snapshot.paramMap.get('module');
        this.id = this.route.snapshot.paramMap.get('id');
        this.doc = api[module].find(d => d.tag ? d.tag === this.id : d.name === this.id);
        this.title.setTitle(`${baseTitle(this.title.getTitle())} | ${this.id}`);
    }
};
ApiDocComponent.ctorParameters = () => [
    { type: Title },
    { type: ActivatedRoute },
    { type: undefined, decorators: [{ type: Inject, args: [LIBRARY_API,] }] }
];
ApiDocComponent = __decorate([
    Component({
        template: "<article class=\"component-readme\">\n    <div class=\"breadcrumbs\">\n        <a [routerLink]=\"['../../']\">API</a><span class=\"sep\">/</span><span class=\"id\">{{id}}</span>\n    </div>\n    <ad-markdown [data]=\"doc.readme\"></ad-markdown>\n    <ad-api [doc]=\"doc\"></ad-api>\n</article>\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [":host{display:block}:host .breadcrumbs{margin-bottom:1rem}:host .breadcrumbs .sep{color:var(--anj-border-dark);margin:0 .5rem}:host .breadcrumbs .id{color:var(--anj-neutral)}"]
    }),
    __param(2, Inject(LIBRARY_API)),
    __metadata("design:paramtypes", [Title, ActivatedRoute, Object])
], ApiDocComponent);

let ApiListComponent = class ApiListComponent {
    constructor(api) {
        this.api = api;
        this.filtered = this.api;
    }
    filter({ detail }) {
        const query = detail.value.toLowerCase();
        const filtered = {};
        for (const module in this.api) {
            if (this.api.hasOwnProperty(module)) {
                const mFiltered = this.api[module].filter(d => this.nameFromDoc(d).toLowerCase().includes(query));
                if (mFiltered.length > 0) {
                    filtered[module] = mFiltered;
                }
            }
        }
        this.filtered = Object.keys(filtered).length > 0 ? filtered : undefined;
    }
    apiPath(module, doc) {
        return `${module}/${this.nameFromDoc(doc)}`;
    }
    nameFromDoc(doc) {
        return doc.tag ? doc.tag : doc.name;
    }
};
ApiListComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [LIBRARY_API,] }] }
];
ApiListComponent = __decorate([
    Component({
        template: "<anj-form-group>\n    <anj-filter placeholder=\"Search\" (anjFilter)=\"filter($event)\"></anj-filter>\n</anj-form-group>\n<ng-container *ngIf=\"filtered; else noResults\">\n    <section *ngFor=\"let lib of filtered | keyvalue\">\n        <anj-headline><h3>{{lib.key}}</h3></anj-headline>\n        <div class=\"row results-container\">\n            <div *ngFor=\"let doc of lib.value\" class=\"col-12 col-sm-6 col-md-4 col-lg-3 result\">\n                <a [routerLink]=\"apiPath(lib.key, doc)\">{{nameFromDoc(doc)}}</a>\n            </div>\n        </div>\n    </section>\n</ng-container>\n<ng-template #noResults>\n    <p>No matches found.</p>\n</ng-template>\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [":host{display:block}:host anj-headline{border-bottom:1px solid var(--anj-border);padding-bottom:.75rem;margin-bottom:1rem}:host .results-container{margin-bottom:2rem}:host .result{margin-bottom:.5rem}"]
    }),
    __param(0, Inject(LIBRARY_API)),
    __metadata("design:paramtypes", [Object])
], ApiListComponent);

const LIBRARY_VERSION = new InjectionToken('LibraryVersion');
let VersionPipe = class VersionPipe {
    constructor(version) {
        this.version = version;
    }
    transform(value) {
        if (!this.version) {
            return value;
        }
        const val = value.default ? value.default : value;
        return val.replace(/0.0.0/g, this.version);
    }
};
VersionPipe.ctorParameters = () => [
    { type: String, decorators: [{ type: Optional }, { type: Inject, args: [LIBRARY_VERSION,] }] }
];
VersionPipe = __decorate([
    Pipe({
        name: 'version'
    }),
    __param(0, Optional()), __param(0, Inject(LIBRARY_VERSION)),
    __metadata("design:paramtypes", [String])
], VersionPipe);

let ExternalDocComponent = class ExternalDocComponent {
    constructor(docs, route, version) {
        this.docs = docs;
        this.route = route;
        this.version = version;
        this.doc$ = this.route.paramMap.pipe(switchMap((params) => of(version.transform(this.docs[params.get('id')]))));
    }
};
ExternalDocComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [MODULE_DOCS,] }] },
    { type: ActivatedRoute },
    { type: VersionPipe }
];
ExternalDocComponent = __decorate([
    Component({
        template: '<ad-markdown [data]="doc$ | async"></ad-markdown>',
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __param(0, Inject(MODULE_DOCS)),
    __metadata("design:paramtypes", [Object, ActivatedRoute, VersionPipe])
], ExternalDocComponent);

let ExternalModuleComponent = class ExternalModuleComponent {
    constructor(docs, name, service) {
        this.docs = docs;
        this.name = name;
        this.service = service;
        const path = name.toLowerCase();
        this.service.menuItems = Object.keys(docs).map((doc) => {
            return {
                link: `${path}/${doc}`,
                name: doc.split('-').join(' ')
            };
        });
    }
};
ExternalModuleComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [MODULE_DOCS,] }] },
    { type: String, decorators: [{ type: Inject, args: [MODULE_NAME,] }] },
    { type: DocsService }
];
ExternalModuleComponent = __decorate([
    Component({
        template: '<router-outlet></router-outlet>',
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __param(0, Inject(MODULE_DOCS)), __param(1, Inject(MODULE_NAME)),
    __metadata("design:paramtypes", [Object, String, DocsService])
], ExternalModuleComponent);

let FeatureComponent = class FeatureComponent {
    constructor(route, changeRef, title, docs, frameWorkType) {
        this.route = route;
        this.changeRef = changeRef;
        this.title = title;
        this.docs = docs;
        this.frameWorkType = frameWorkType;
        this.route.params.subscribe({
            next: (params) => {
                const doc = this.docs.find((d) => {
                    return d.tag ? d.tag === params.id : d.name === params.id;
                });
                this.doc = this.filterExamples(doc);
                this.title.setTitle(this.titleFromDoc(this.title.getTitle()));
                this.changeRef.markForCheck();
            }
        });
    }
    sortedKeys(usages) {
        const keys = Object.keys(usages);
        const firstIndex = keys.findIndex(k => k === 'usage' || k === 'angular' || k === 'vue');
        return keys.splice(firstIndex, 1).concat(keys);
    }
    titleFromDoc(title) {
        const base = baseTitle(title);
        if (!this.doc) {
            return base;
        }
        return `${base} | ${this.doc.tag ? titleFromTag(this.doc.tag) : titleFromName(this.doc.name)}`;
    }
    filterExamples(doc) {
        if (this.frameWorkType === FrameworkType.angular) {
            return this.getNgExamples(doc);
        }
        else if (this.frameWorkType === FrameworkType.vue) {
            return this.getVueExamples(doc);
        }
        else if (this.frameWorkType === FrameworkType.javascript) {
            return this.getJsExamples(doc);
        }
        return doc;
    }
    // Return ng examples, if existing. Otherwise, js examples.
    getNgExamples(doc) {
        const usages = {};
        if (doc.usage.angular) {
            for (const u in doc.usage) {
                if (u === 'angular' || u.startsWith('ng-')) {
                    usages[u] = doc.usage[u];
                }
            }
            doc.usage = usages;
            return doc;
        }
        else {
            return this.getJsExamples(doc);
        }
    }
    // Return js examples.
    getJsExamples(doc) {
        const usages = {};
        for (const u in doc.usage) {
            if (u !== 'angular' && !u.startsWith('ng-') &&
                u !== 'vue' && !u.startsWith('vue-')) {
                usages[u] = doc.usage[u];
            }
        }
        doc.usage = usages;
        return doc;
    }
    // Return vue examples, if existing. Otherwise, js examples.
    getVueExamples(doc) {
        const usages = {};
        if (doc.usage.vue) {
            for (const u in doc.usage) {
                if (u === 'vue' || u.startsWith('vue-')) {
                    usages[u] = doc.usage[u];
                }
            }
            doc.usage = usages;
            return doc;
        }
        else {
            return this.getJsExamples(doc);
        }
    }
};
FeatureComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: ChangeDetectorRef },
    { type: Title },
    { type: Array, decorators: [{ type: Inject, args: [MODULE_DOCS,] }] },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MODULE_TYPE,] }] }
];
FeatureComponent = __decorate([
    Component({
        template: "<div class=\"row\">\n    <div [ngClass]=\"doc.usage ? 'col-12 col-lg-10' : 'col-12'\">\n        <article class=\"component-readme\" id=\"overview\">\n            <ad-markdown [data]=\"doc.readme\"></ad-markdown>\n        </article>\n        <article *ngFor=\"let key of sortedKeys(doc.usage)\" id=\"{{key}}\">\n            <ad-use-case [usage]=\"doc.usage[key]\"></ad-use-case>\n        </article>\n        <ad-api [doc]=\"doc\"></ad-api>\n    </div>\n    <div *ngIf=\"doc.usage\" class=\"d-none d-lg-flex col-lg-2 toc-wrapper\">\n        <ad-toc [docs]=\"doc.usage\" [keys]=\"sortedKeys(doc.usage)\"></ad-toc>\n    </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [".component-readme{margin-bottom:2.5rem}"]
    }),
    __param(3, Inject(MODULE_DOCS)),
    __param(4, Optional()), __param(4, Inject(MODULE_TYPE)),
    __metadata("design:paramtypes", [ActivatedRoute,
        ChangeDetectorRef,
        Title, Array, String])
], FeatureComponent);

let HomeComponent = class HomeComponent {
    constructor(title, service, getStartedUrl, readme) {
        this.title = title;
        this.service = service;
        this.getStartedUrl = getStartedUrl;
        this.readme = readme;
        this.service.menuItems = null;
        this.title.setTitle(baseTitle(this.title.getTitle()));
    }
};
HomeComponent.ctorParameters = () => [
    { type: Title },
    { type: DocsService },
    { type: String, decorators: [{ type: Optional }, { type: Inject, args: [GET_STARTED_URL,] }] },
    { type: String, decorators: [{ type: Inject, args: [HOME_README,] }] }
];
HomeComponent = __decorate([
    Component({
        template: "<article>\n    <ad-markdown [data]=\"readme\"></ad-markdown>\n    <p *ngIf=\"getStartedUrl\" class=\"text-center pt-4\">\n        <anj-button [routerLink]=\"getStartedUrl\">Get Started</anj-button>\n    </p>\n</article>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __param(2, Optional()), __param(2, Inject(GET_STARTED_URL)),
    __param(3, Inject(HOME_README)),
    __metadata("design:paramtypes", [Title,
        DocsService, String, String])
], HomeComponent);

let IntroComponent = class IntroComponent {
    constructor(title, readme, moduleName, getStartedUrl) {
        this.title = title;
        this.readme = readme;
        this.moduleName = moduleName;
        this.getStartedUrl = getStartedUrl;
        this.title.setTitle(`${baseTitle(this.title.getTitle())} | ${moduleName}`);
    }
};
IntroComponent.ctorParameters = () => [
    { type: Title },
    { type: String, decorators: [{ type: Inject, args: [MODULE_README,] }] },
    { type: String, decorators: [{ type: Inject, args: [MODULE_NAME,] }] },
    { type: String, decorators: [{ type: Optional }, { type: Inject, args: [MODULE_GET_STARTED_URL,] }] }
];
IntroComponent = __decorate([
    Component({
        selector: 'ad-components',
        template: "<article>\n    <ad-markdown [data]=\"readme | version\"></ad-markdown>\n    <p *ngIf=\"getStartedUrl\" class=\"text-center pt-4\">\n        <anj-button [routerLink]=\"getStartedUrl\">Try It</anj-button>\n    </p>\n</article>\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [":host::ng-deep ad-markdown p[align=center]{display:none}"]
    }),
    __param(1, Inject(MODULE_README)),
    __param(2, Inject(MODULE_NAME)),
    __param(3, Optional()), __param(3, Inject(MODULE_GET_STARTED_URL)),
    __metadata("design:paramtypes", [Title, String, String, String])
], IntroComponent);

class JsDemo {
    constructor(element, demo) {
        element.nativeElement.appendChild(document.createRange().createContextualFragment(demo));
    }
}

let UseCaseComponent = class UseCaseComponent {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    ngOnChanges() {
        const docs = this.usage.split('<!-- Demo -->');
        this.doc = docs[0].trim();
        this.demo = docs[1] ? this.sanitizer.bypassSecurityTrustHtml(docs[1] ? docs[1].trim() : '') : undefined;
        if (docs[2]) {
            const tabs = {};
            docs[2].trim().split('```').forEach((s) => {
                s = s.trim();
                if (s) {
                    tabs[s.split(/\n/)[0].trim()] = `${'```'}${s}${'```'}`;
                }
            });
            this.tabs = tabs;
        }
    }
    switchTabs(tab) {
        this.activeTab = tab ? tab : this.activeTab ? undefined : Object.keys(this.tabs)[0];
    }
    getTitle(doc) {
        return doc.split('\n')[0].replace(/#/g, '').trim();
    }
    codeType(type) {
        return type.includes('typescript') ? 'ts' : type;
    }
};
UseCaseComponent.ctorParameters = () => [
    { type: DomSanitizer }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], UseCaseComponent.prototype, "usage", void 0);
UseCaseComponent = __decorate([
    Component({
        selector: 'ad-use-case',
        template: "<ad-markdown [data]=\"doc\"></ad-markdown>\n<anj-card *ngIf=\"demo\" elevation=\"1\">\n    <anj-card-header>\n        <anj-headline>\n            <h3>{{getTitle(doc)}}</h3>\n            <anj-button context=\"icon\" (click)=\"switchTabs()\" title=\"View Source\">\n                <svg slot=\"icon-only\" xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\">\n                    <path d=\"M9.4 16.6L4.8 12l4.6-4.6L8 6l-6 6 6 6 1.4-1.4zm5.2 0l4.6-4.6-4.6-4.6L16 6l6 6-6 6-1.4-1.4z\"/>\n                </svg>\n            </anj-button>\n        </anj-headline>\n    </anj-card-header>\n    <anj-card-body>\n        <div class=\"example-container\" [class.anj-active]=\"activeTab\">\n            <anj-tabs>\n                <anj-tab *ngFor=\"let t of tabs | keyvalue\" (click)=\"switchTabs(t.key)\" [class.anj-active]=\"t.key === activeTab\">{{codeType(t.key)}}</anj-tab>\n            </anj-tabs>\n            <div class=\"example\">\n                <ad-markdown *ngFor=\"let t of tabs | keyvalue\" [data]=\"t.value\" [class.anj-active]=\"t.key === activeTab\"></ad-markdown>\n            </div>\n        </div>\n        <div *ngIf=\"demo\" class=\"demo-container\" [innerHTML]=\"demo\"></div>\n    </anj-card-body>\n</anj-card>\n",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [":host{border-bottom:1px solid var(--anj-border);display:block;margin-bottom:3rem;padding-bottom:3.5rem}:host anj-card{margin-top:2rem}:host anj-tab{text-transform:uppercase}:host .example-container{margin:0 -1.25rem}:host .example-container:not(.anj-active){height:0;overflow:hidden}:host .example{background-color:var(--anj-background);border-bottom:1px solid var(--anj-border);margin:0 0 1rem;padding:1rem}:host .example ad-markdown{display:none}:host .example ad-markdown.anj-active{display:block}"]
    }),
    __metadata("design:paramtypes", [DomSanitizer])
], UseCaseComponent);

let AnjunaDocsModule = class AnjunaDocsModule {
};
AnjunaDocsModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            RouterModule
        ],
        declarations: [
            ApiComponent,
            ApiDocComponent,
            ApiListComponent,
            ExternalDocComponent,
            ExternalModuleComponent,
            FeatureComponent,
            HomeComponent,
            IntroComponent,
            UseCaseComponent,
            VersionPipe
        ],
        exports: [
            ApiComponent,
            ApiDocComponent,
            ApiListComponent,
            ExternalDocComponent,
            ExternalModuleComponent,
            FeatureComponent,
            HomeComponent,
            IntroComponent
        ],
        entryComponents: [
            ApiComponent,
            ApiDocComponent,
            ApiListComponent,
            FeatureComponent,
            HomeComponent,
            IntroComponent
        ],
        providers: [
            VersionPipe
        ],
        schemas: [
            CUSTOM_ELEMENTS_SCHEMA
        ]
    })
], AnjunaDocsModule);

/* Components */

/**
 * Generated bundle index. Do not edit.
 */

export { AnjunaDocsModule, ApiComponent, ApiDocComponent, ApiListComponent, DEMO_COMPONENTS, DocsService, ExternalDocComponent, ExternalModuleComponent, FeatureComponent, FrameworkType, GET_STARTED_URL, HOME_README, HomeComponent, IntroComponent, JsDemo, LIBRARY_API, LIBRARY_VERSION, MODULE_DOCS, MODULE_GET_STARTED_URL, MODULE_NAME, MODULE_README, MODULE_TYPE, VersionPipe, baseTitle, titleFromName, titleFromTag, UseCaseComponent as ɵa };
//# sourceMappingURL=anjuna-angular-docs.js.map
